# reference related constants
VALID_REF_FORMAT = ["fasta", "vcf", "text", "gtf", "gff"]
VALID_GENOME_VER = ["hg19", "hg38", "canfam3"]

# reference files
REFERENCE_FILES = {
    "hg38": {
        "reference_genome": {
            "url": "gs://genomics-public-data/resources/broad/hg38/v0/Homo_sapiens_assembly38.fasta",
            "file_type": "fasta",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "Homo_sapiens_assembly38.fasta",
            "output_path": "genome",
        },
        "dbsnp": {
            "url": "gs://genomics-public-data/resources/broad/hg38/v0/Homo_sapiens_assembly38.dbsnp138.vcf",
            "file_type": "vcf",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "Homo_sapiens_assembly38.dbsnp138.vcf",
            "output_path": "variants",
        },
        "hc_vcf_1kg": {
            "url": "gs://genomics-public-data/resources/broad/hg38/v0/1000G_phase1.snps.high_confidence.hg38.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg38",
            "output_file": "1000G_phase1.snps.high_confidence.hg38.vcf",
            "output_path": "variants",
        },
        "mills_1kg": {
            "url": "gs://genomics-public-data/resources/broad/hg38/v0/Mills_and_1000G_gold_standard.indels.hg38.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg38",
            "output_file": "Mills_and_1000G_gold_standard.indels.hg38.vcf",
            "output_path": "variants",
        },
        "known_indel_1kg": {
            "url": "gs://genomics-public-data/resources/broad/hg38/v0/Homo_sapiens_assembly38.known_indels.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg38",
            "output_file": "Homo_sapiens_assembly38.known_indels.vcf",
            "output_path": "variants",
        },
        "vcf_1kg": {
            "url": "gs://genomics-public-data/resources/broad/hg38/v0/1000G.phase3.integrated.sites_only.no_MATCHED_REV.hg38.vcf",
            "file_type": "vcf",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "1000G.phase3.integrated.sites_only.no_MATCHED_REV.hg38.vcf",
            "output_path": "variants",
        },
        "gnomad_variant": {
            "url": "gs://gcp-public-data--gnomad/release/2.1.1/liftover_grch38/vcf/genomes/gnomad.genomes.r2.1.1.sites.liftover_grch38.vcf.bgz",
            "file_type": "vcf",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "gnomad.genomes.r2.1.1.sites.vcf.bgz",
            "output_path": "variants",
        },
        "gnomad_variant_index": {
            "url": "gs://gcp-public-data--gnomad/release/2.1.1/liftover_grch38/vcf/genomes/gnomad.genomes.r2.1.1.sites.liftover_grch38.vcf.bgz.tbi",
            "file_type": "vcf",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "gnomad.genomes.r2.1.1.sites.vcf.bgz.tbi",
            "output_path": "variants",
        },
        "cosmicdb": {
            "url": "https://cancer.sanger.ac.uk/cosmic/file_download/GRCh38/cosmic/v97/VCF/CosmicCodingMuts.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg38",
            "output_file": "cosmic_coding_muts_v97.vcf",
            "output_path": "variants",
        },
        "wgs_calling": {
            "url": "gs://genomics-public-data/resources/broad/hg38/v0/wgs_calling_regions.hg38.interval_list",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "wgs_calling_regions.v1",
            "output_path": "genome",
        },
        "genome_chrom_size": {
            "url": "https://hgdownload.cse.ucsc.edu/goldenPath/hg38/bigZips/hg38.chrom.sizes",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "hg38.chrom.sizes",
            "output_path": "genome",
        },
        "refgene_txt": {
            "url": "http://hgdownload.cse.ucsc.edu/goldenPath/hg38/database/refGene.txt.gz",
            "file_type": "text",
            "gzip": True,
            "genome_version": "hg38",
            "output_file": "refGene.txt",
            "output_path": "genome",
        },
        "refgene_sql": {
            "url": "http://hgdownload.cse.ucsc.edu/goldenPath/hg38/database/refGene.sql",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "refGene.sql",
            "output_path": "genome",
        },
        "rankscore": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/master/cancer/rank_model/cancer_rank_model_-v0.1-.ini",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "cancer_rank_model_-v0.1-.ini",
            "output_path": "genome",
        },
        "access_regions": {
            "url": "https://raw.githubusercontent.com/etal/cnvkit/master/data/access-5k-mappable.hg19.bed",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "access_5kb_hg38.txt",
            "output_path": "genome",
        },
        "delly_exclusion": {
            "url": "https://raw.githubusercontent.com/dellytools/delly/master/excludeTemplates/human.hg38.excl.tsv",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "delly_exclusion.tsv",
            "output_path": "genome",
        },
        "delly_mappability": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/ea051b864d18945980f0ded6b16a5d192bd736a5/cancer/references/GRCh38.delly.blacklist.gz",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "delly_mappability.gz",
            "output_path": "genome",
        },
        "delly_mappability_gindex": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/ea051b864d18945980f0ded6b16a5d192bd736a5/cancer/references/GRCh38.delly.blacklist.gz.gzi",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "delly_mappability.gz.gzi",
            "output_path": "genome",
        },
        "delly_mappability_findex": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/ea051b864d18945980f0ded6b16a5d192bd736a5/cancer/references/GRCh38.delly.blacklist.gz.fai",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "delly_mappability.gz.fai",
            "output_path": "genome",
        },
        "ascat_gccorrection": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/35465e2644f76f2d59427a9b379d34ecea71f259/cancer/references/hg38_SnpGcCorrections.tsv.gz",
            "file_type": "text",
            "gzip": True,
            "genome_version": "hg38",
            "output_file": "hg38_SnpGcCorrections.tsv",
            "output_path": "genome",
        },
        "ascat_chryloci": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/ea051b864d18945980f0ded6b16a5d192bd736a5/cancer/references/hg38_Y.loci",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg38",
            "output_file": "hg38_Y.loci",
            "output_path": "genome",
        },
        "clinvar": {
            "url": "https://ftp.ncbi.nlm.nih.gov/pub/clinvar/vcf_GRCh38/clinvar.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg38",
            "output_file": "clinvar.vcf",
            "output_path": "variants",
        },
        "somalier_sites": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/87f22d3f458569afbcb4d7f1588468d21d1751fb/cancer/references/hg38.somalier.sites.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg38",
            "output_file": "hg38.somalier.sites.vcf",
            "output_path": "variants",
        },
    },
    "hg19": {
        "reference_genome": {
            "url": "gs://gatk-legacy-bundles/b37/human_g1k_v37.fasta.gz",
            "file_type": "fasta",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "human_g1k_v37.fasta",
            "output_path": "genome",
        },
        "dbsnp": {
            "url": "gs://gatk-legacy-bundles/b37/dbsnp_138.b37.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "dbsnp_grch37_b138.vcf",
            "output_path": "variants",
        },
        "hc_vcf_1kg": {
            "url": "gs://gatk-legacy-bundles/b37/1000G_phase1.snps.high_confidence.b37.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "1kg_phase1_snps_high_confidence_b37.vcf",
            "output_path": "variants",
        },
        "mills_1kg": {
            "url": "gs://gatk-legacy-bundles/b37/Mills_and_1000G_gold_standard.indels.b37.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "mills_1kg_index.vcf",
            "output_path": "variants",
        },
        "known_indel_1kg": {
            "url": "gs://gatk-legacy-bundles/b37/1000G_phase1.indels.b37.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "1kg_known_indels_b37.vcf",
            "output_path": "variants",
        },
        "vcf_1kg": {
            "url": "gs://genomics-public-data/ftp-trace.ncbi.nih.gov/1000genomes/ftp/release/20130502/ALL.wgs.phase3_shapeit2_mvncall_integrated_v5a.20130502.sites.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "1k_genome_wgs_p1_v3_all_sites.vcf",
            "output_path": "variants",
        },
        "gnomad_variant": {
            "url": "gs://gcp-public-data--gnomad/release/2.1.1/vcf/genomes/gnomad.genomes.r2.1.1.sites.vcf.bgz",
            "file_type": "vcf",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "gnomad.genomes.r2.1.1.sites.vcf.bgz",
            "output_path": "variants",
        },
        "gnomad_variant_index": {
            "url": "gs://gcp-public-data--gnomad/release/2.1.1/vcf/genomes/gnomad.genomes.r2.1.1.sites.vcf.bgz.tbi",
            "file_type": "vcf",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "gnomad.genomes.r2.1.1.sites.vcf.bgz.tbi",
            "output_path": "variants",
        },
        "cosmicdb": {
            "url": "https://cancer.sanger.ac.uk/cosmic/file_download/GRCh37/cosmic/v97/VCF/CosmicCodingMuts.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "cosmic_coding_muts_v97.vcf",
            "output_path": "variants",
        },
        "wgs_calling": {
            "url": "gs://gatk-legacy-bundles/b37/wgs_calling_regions.v1.interval_list",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "wgs_calling_regions.v1",
            "output_path": "genome",
        },
        "genome_chrom_size": {
            "url": "https://hgdownload.cse.ucsc.edu/goldenPath/hg19/bigZips/hg19.chrom.sizes",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "hg19.chrom.sizes",
            "output_path": "genome",
        },
        "refgene_txt": {
            "url": "http://hgdownload.cse.ucsc.edu/goldenPath/hg19/database/refGene.txt.gz",
            "file_type": "text",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "refGene.txt",
            "output_path": "genome",
        },
        "refgene_sql": {
            "url": "http://hgdownload.cse.ucsc.edu/goldenPath/hg19/database/refGene.sql",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "refGene.sql",
            "output_path": "genome",
        },
        "rankscore": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/master/cancer/rank_model/cancer_rank_model_-v0.1-.ini",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "cancer_rank_model_-v0.1-.ini",
            "output_path": "genome",
        },
        "access_regions": {
            "url": "https://raw.githubusercontent.com/etal/cnvkit/master/data/access-5k-mappable.hg19.bed",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "access_5kb_hg19.txt",
            "output_path": "genome",
        },
        "delly_exclusion": {
            "url": "https://raw.githubusercontent.com/dellytools/delly/master/excludeTemplates/human.hg19.excl.tsv",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "delly_exclusion.tsv",
            "output_path": "genome",
        },
        "delly_mappability": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/86aab2d10c5ffc009bc8c68ad077ab7283d8fe06/cancer/references/GRCh37.delly.blacklist.gz",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "delly_mappability.gz",
            "output_path": "genome",
        },
        "delly_mappability_gindex": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/86aab2d10c5ffc009bc8c68ad077ab7283d8fe06/cancer/references/GRCh37.delly.blacklist.gz.gzi",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "delly_mappability.gz.gzi",
            "output_path": "genome",
        },
        "delly_mappability_findex": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/86aab2d10c5ffc009bc8c68ad077ab7283d8fe06/cancer/references/GRCh37.delly.blacklist.gz.fai",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "delly_mappability.gz.fai",
            "output_path": "genome",
        },
        "ascat_gccorrection": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/12a6c760fd542c02de2cda286b6245e46f4b6a97/cancer/references/GRCh37_SnpGcCorrections.tsv.gz",
            "file_type": "text",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "GRCh37_SnpGcCorrections.tsv",
            "output_path": "genome",
        },
        "ascat_chryloci": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/12a6c760fd542c02de2cda286b6245e46f4b6a97/cancer/references/GRCh37_d5_Y.loci",
            "file_type": "text",
            "gzip": False,
            "genome_version": "hg19",
            "output_file": "GRCh37_Y.loci",
            "output_path": "genome",
        },
        "clinvar": {
            "url": "https://ftp.ncbi.nlm.nih.gov/pub/clinvar/vcf_GRCh37/clinvar.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "clinvar.vcf",
            "output_path": "variants",
        },
        "somalier_sites": {
            "url": "https://raw.githubusercontent.com/Clinical-Genomics/reference-files/87f22d3f458569afbcb4d7f1588468d21d1751fb/cancer/references/GRCh37.somalier.sites.vcf.gz",
            "file_type": "vcf",
            "gzip": True,
            "genome_version": "hg19",
            "output_file": "GRCh37.somalier.sites.vcf",
            "output_path": "variants",
        },
    },
    "canfam3": {
        "reference_genome": {
            "url": "https://hgdownload.cse.ucsc.edu/goldenPath/canFam3/bigZips/canFam3.fa.gz",
            "file_type": "fasta",
            "gzip": True,
            "genome_version": "canfam3",
            "output_file": "canFam3.fasta",
            "output_path": "genome",
        },
        "refgene_txt": {
            "url": "https://hgdownload.cse.ucsc.edu/goldenPath/canFam3/database/refGene.txt.gz",
            "file_type": "text",
            "gzip": True,
            "genome_version": "canfam3",
            "output_file": "canfam3_refGene.txt",
            "output_path": "genome",
        },
        "refgene_sql": {
            "url": "https://hgdownload.cse.ucsc.edu/goldenPath/canFam3/database/refGene.sql",
            "file_type": "text",
            "gzip": False,
            "genome_version": "canfam3",
            "output_file": "canfam3_refGene.sql",
            "output_path": "genome",
        },
        "genome_chrom_size": {
            "url": "https://hgdownload.cse.ucsc.edu/goldenPath/canFam3/bigZips/canFam3.chrom.sizes",
            "file_type": "text",
            "gzip": False,
            "genome_version": "canfam3",
            "output_file": "canfam3.chrom.sizes",
            "output_path": "genome",
        },
    },
}
